@@ -9,7 +9,8 @@ def python_build(*args):
     if platform == "darwin":
         osx_version = check_output(["sw_vers", "-productVersion"]).replace('\n', '')
         if osx_version in ["10.9", "10.10"]:
-            environment_vars.update({"CFLAGS": "-I$(xcrun --show-sdk-path)/usr/include"})
+            sdk_path = check_output(["xcrun", "--show-sdk-path"])
+            environment_vars.update({"CFLAGS": "-I{}/usr/include".format(sdk_path)})
     pyenv_build_bin = path.join(PYTHONBUILD_DIR, "bin", "python-build")
     call([pyenv_build_bin] + list(args), env=environment_vars)
 
